pub struct CompiledExpr { /* private fields */ }Expand description
A compiled expression: flat bytecode evaluated on a stack VM.
Implementations
Sourceimpl CompiledExpr
impl CompiledExpr
pub fn new(bytecode: ExprBytecode) -> Self
Sourcepub fn eval_u64(&self, memory: *mut u8) -> u64
pub fn eval_u64(&self, memory: *mut u8) -> u64
Evaluate against raw simulator memory, returning the result as u64. For wide results, returns the low 64 bits.
Sourcepub fn eval_value(&self, memory: *mut u8) -> TestbenchValue
pub fn eval_value(&self, memory: *mut u8) -> TestbenchValue
Evaluate and return the full TestbenchValue (preserves wide results).
pub fn eval_bool(&self, memory: *mut u8) -> bool
Sourcepub fn constant_u64(&self) -> Option<u64>
pub fn constant_u64(&self) -> Option<u64>
Returns the value when this expression does not read simulator memory.